pub struct QueryCombinationIter<'w, 's, Q, F, const K: usize>where
Q: WorldQuery,
F: ReadOnlyWorldQuery,{ /* private fields */ }Expand description
An iterator over K-sized combinations of query items without repetition.
A combination is an arrangement of a collection of items where order does not matter.
K is the number of items that make up each subset, and the number of items returned by the iterator.
N is the number of total entities output by the query.
For example, given the list [1, 2, 3, 4], where K is 2, the combinations without repeats are
[1, 2], [1, 3], [1, 4], [2, 3], [2, 4], [3, 4].
And in this case, N would be defined as 4 since the size of the input list is 4.
The number of combinations depend on how K relates to the number of entities matching the Query:
- if
K = N, only one combination exists, - if
K < N, there are NCK combinations (see the performance section ofQuery), - if
K > N, there are no combinations.
The output combination is not guaranteed to have any order of iteration.
Usage
This type is returned by calling Query::iter_combinations or Query::iter_combinations_mut.
It implements Iterator only if it iterates over read-only query items (learn more).
In the case of mutable query items, it can be iterated by calling fetch_next in a while let loop.
Examples
The following example shows how to traverse the iterator when the query items are read-only.
fn some_system(query: Query<&ComponentA>) {
for [a1, a2] in query.iter_combinations() {
// ...
}
}The following example shows how fetch_next should be called with a while let loop to traverse the iterator when the query items are mutable.
fn some_system(mut query: Query<&mut ComponentA>) {
let mut combinations = query.iter_combinations_mut();
while let Some([a1, a2]) = combinations.fetch_next() {
// ...
}
}Implementations
Sourceimpl<'w, 's, Q, F, const K: usize> QueryCombinationIter<'w, 's, Q, F, K>where
Q: WorldQuery,
F: ReadOnlyWorldQuery,
impl<'w, 's, Q, F, const K: usize> QueryCombinationIter<'w, 's, Q, F, K>where
Q: WorldQuery,
F: ReadOnlyWorldQuery,
Sourcepub fn fetch_next(&mut self) -> Option<[<Q as WorldQuery>::Item<'_>; K]>
pub fn fetch_next(&mut self) -> Option<[<Q as WorldQuery>::Item<'_>; K]>
Get next combination of queried components