FunctionSystem

Struct FunctionSystem 

pub struct FunctionSystem<Marker, F>
where F: SystemParamFunction<Marker>,
{ /* private fields */ }
The System counter part of an ordinary function.

You get this by calling IntoSystem::into_system on a function that only accepts SystemParams. The output of the system becomes the functions return type, while the input becomes the functions In tagged parameter or () if no such parameter exists.

FunctionSystem must be .initialized before they can be run.

The Clone implementation for FunctionSystem returns a new instance which is NOT initialized. The cloned system must also be .initialized before it can be run.