pub struct ScanCode(pub u32);Expand description
The scan code of a KeyboardInput.
Usage
It is used as the generic <T> value of an Input to create a Res<Input<ScanCode>>.
The resource values are mapped to the physical location of a key on the keyboard and correlate to an KeyCode
Updating
The resource is updated inside of the keyboard_input_system.
Tuple Fields
0: u32Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ScanCode
impl<'de> Deserialize<'de> for ScanCode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ScanCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ScanCode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<QwertyScanCode> for ScanCode
impl From<QwertyScanCode> for ScanCode
Sourcefn from(value: QwertyScanCode) -> ScanCode
fn from(value: QwertyScanCode) -> ScanCode
Converts to this type from the input type.
Sourceimpl FromReflect for ScanCodewhere
u32: FromReflect,
impl FromReflect for ScanCodewhere
u32: FromReflect,
Sourcefn from_reflect(reflect: &(dyn Reflect + 'static)) -> Option<ScanCode>
fn from_reflect(reflect: &(dyn Reflect + 'static)) -> Option<ScanCode>
Constructs a concrete instance of
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn Reflect>,
) -> Result<Self, Box<dyn Reflect>>
fn take_from_reflect( reflect: Box<dyn Reflect>, ) -> Result<Self, Box<dyn Reflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl GetTypeRegistration for ScanCodewhere
u32: FromReflect,
impl GetTypeRegistration for ScanCodewhere
u32: FromReflect,
Sourceimpl Ord for ScanCode
impl Ord for ScanCode
Sourceimpl PartialOrd for ScanCode
impl PartialOrd for ScanCode
Sourceimpl Reflect for ScanCodewhere
u32: FromReflect,
impl Reflect for ScanCodewhere
u32: FromReflect,
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
fn as_any_mut(&mut self) -> &mut (dyn Any + 'static)
Returns the value as a
&mut dyn Any.Sourcefn into_reflect(self: Box<ScanCode>) -> Box<dyn Reflect>
fn into_reflect(self: Box<ScanCode>) -> Box<dyn Reflect>
Casts this type to a boxed reflected value.
Sourcefn as_reflect(&self) -> &(dyn Reflect + 'static)
fn as_reflect(&self) -> &(dyn Reflect + 'static)
Casts this type to a reflected value.
Sourcefn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
fn as_reflect_mut(&mut self) -> &mut (dyn Reflect + 'static)
Casts this type to a mutable reflected value.
Sourcefn clone_value(&self) -> Box<dyn Reflect>
fn clone_value(&self) -> Box<dyn Reflect>
Clones the value as a
Reflect trait object. Read moreSourcefn set(&mut self, value: Box<dyn Reflect>) -> Result<(), Box<dyn Reflect>>
fn set(&mut self, value: Box<dyn Reflect>) -> Result<(), Box<dyn Reflect>>
Performs a type-checked assignment of a reflected value to this value. Read more
Sourcefn apply(&mut self, value: &(dyn Reflect + 'static))
fn apply(&mut self, value: &(dyn Reflect + 'static))
Applies a reflected value to this value. Read more
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an enumeration of “kinds” of type. Read more
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
Sourcefn reflect_owned(self: Box<ScanCode>) -> ReflectOwned
fn reflect_owned(self: Box<ScanCode>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
Sourcefn reflect_partial_eq(&self, value: &(dyn Reflect + 'static)) -> Option<bool>
fn reflect_partial_eq(&self, value: &(dyn Reflect + 'static)) -> Option<bool>
Returns a “partial equality” comparison result. Read more
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
Sourcefn serializable(&self) -> Option<Serializable<'_>>
fn serializable(&self) -> Option<Serializable<'_>>
Returns a serializable version of the value. Read more
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
Sourceimpl Serialize for ScanCode
impl Serialize for ScanCode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TupleStruct for ScanCodewhere
u32: FromReflect,
impl TupleStruct for ScanCodewhere
u32: FromReflect,
Sourcefn field(&self, index: usize) -> Option<&(dyn Reflect + 'static)>
fn field(&self, index: usize) -> Option<&(dyn Reflect + 'static)>
Returns a reference to the value of the field with index
index as a
&dyn Reflect.Sourcefn field_mut(&mut self, index: usize) -> Option<&mut (dyn Reflect + 'static)>
fn field_mut(&mut self, index: usize) -> Option<&mut (dyn Reflect + 'static)>
Returns a mutable reference to the value of the field with index
index
as a &mut dyn Reflect.Sourcefn iter_fields(&self) -> TupleStructFieldIter<'_> ⓘ
fn iter_fields(&self) -> TupleStructFieldIter<'_> ⓘ
Returns an iterator over the values of the tuple struct’s fields.
Sourcefn clone_dynamic(&self) -> DynamicTupleStruct
fn clone_dynamic(&self) -> DynamicTupleStruct
Clones the struct into a
DynamicTupleStruct.Sourceimpl TypePath for ScanCodewhere
u32: FromReflect,
impl TypePath for ScanCodewhere
u32: FromReflect,
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
impl Copy for ScanCode
impl Eq for ScanCode
impl StructuralPartialEq for ScanCode