pub struct RenderPassDescriptor<'tex, 'desc> {
pub label: Option<&'desc str>,
pub color_attachments: &'desc [Option<RenderPassColorAttachment<'tex>>],
pub depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<'tex>>,
}Expand description
Describes the attachments of a render pass.
For use with CommandEncoder::begin_render_pass.
Note: separate lifetimes are needed because the texture views ('tex)
have to live as long as the pass is recorded, while everything else ('desc) doesn’t.
Corresponds to WebGPU GPURenderPassDescriptor.
Fields
label: Option<&'desc str>Debug label of the render pass. This will show up in graphics debuggers for easy identification.
color_attachments: &'desc [Option<RenderPassColorAttachment<'tex>>]The color attachments of the render pass.
depth_stencil_attachment: Option<RenderPassDepthStencilAttachment<'tex>>The depth and stencil attachment of the render pass, if any.