pub struct DynamicSceneBundle {
pub scene: Handle<DynamicScene>,
pub transform: Transform,
pub global_transform: GlobalTransform,
pub visibility: Visibility,
pub computed_visibility: ComputedVisibility,
}Expand description
A component bundle for a DynamicScene root.
The dynamic scene from scene will be spawn as a child of the entity with this component.
Once it’s spawned, the entity will have a SceneInstance component.
Fields
scene: Handle<DynamicScene>Handle to the scene to spawn
transform: Transformglobal_transform: GlobalTransformvisibility: Visibilitycomputed_visibility: ComputedVisibilityTrait Implementations
Sourceimpl Default for DynamicSceneBundle
impl Default for DynamicSceneBundle
Sourcefn default() -> DynamicSceneBundle
fn default() -> DynamicSceneBundle
Returns the “default value” for a type. Read more
impl Bundle for DynamicSceneBundle
impl DynamicBundle for DynamicSceneBundle