pub struct ThreadLockedRawWindowHandleWrapper(/* private fields */);Expand description
A RawHandleWrapper that cannot be sent across threads.
This safely exposes RawWindowHandle and RawDisplayHandle, but care must be taken to ensure that the construction itself is correct.
This can only be constructed via the RawHandleWrapper::get_handle() method;
be sure to read the safety docs there about platform-specific limitations.
In many cases, this should only be constructed on the main thread.