pub struct SpatialAudioSourceBundle<Source = AudioSource>{
pub source: Handle<Source>,
pub settings: PlaybackSettings,
pub spatial: SpatialSettings,
}Expand description
Bundle for playing a sound with a 3D position.
Insert this bundle onto an entity to trigger a sound source to begin playing.
If the handle refers to an unavailable asset (such as if it has not finished loading yet), the audio will not begin playing immediately. The audio will play when the asset is ready.
When Bevy begins the audio playback, a SpatialAudioSink
component will be added to the entity. You can use that component to control the audio
settings during playback.
Fields
source: Handle<Source>Asset containing the audio data to play.
settings: PlaybackSettingsInitial settings that the audio starts playing with.
If you would like to control the audio while it is playing,
query for the SpatialAudioSink component.
Changes to this component will not be applied to already-playing audio.
spatial: SpatialSettingsSpatial audio configuration. Specifies the positions of the source and listener.